@@ -1,4 +1,4 @@
-"Xarchie*archieHost:	archie.sura.net",
+"Xarchie*archieHost:	archie.sura.net(1526)",
 "Xarchie*searchType:	exact",
 "Xarchie*sortType:	name",
 "Xarchie*maxHits:	99",
@@ -130,6 +130,11 @@
 "Xarchie*browserForm.browserPaned.fromVert:	browserDownButton",
 "Xarchie*browserForm.browserPaned.top:		chainTop",
 "Xarchie*browserForm.browserPaned.showGrip:	False",
+"Xarchie*browserForm*List*defaultColumns:	1",
+"Xarchie*browserForm*List*forceColumns:		True",
+"Xarchie*browserForm*List.translations:#override\\n\
+	<Btn1Down>(2):		browser-open-directories() \\n\
+	<Btn1Down>,<Btn1Up>:	Set() Notify() \\n",
 "Xarchie*stringForm.skipAdjust: True",
 "Xarchie*stringForm*Label.justify:	left",
 "Xarchie*stringForm*Label.font:		xarchieFont",
@@ -290,7 +295,6 @@
 "Xarchie*settingsForm*ftpStripButton.fromVert:	ftpTypeButton",
 "Xarchie*settingsForm*ftpStripButton.fromHoriz:	ftpTraceButton",
 "Xarchie*settingsForm*ftpStripButton.horizDistance: 52",
-"Xarchie*settingsForm*ftpStripButton.fromVert:	ftpTypeButton",
 "Xarchie*settingsForm*ftpStripLabel.fromHoriz:	ftpStripButton",
 "Xarchie*settingsForm*ftpStripLabel.fromVert:	ftpTypeButton",
 "Xarchie*settingsForm*ftpStripLabel.font:	xarchieFont",
@@ -449,8 +453,10 @@
 "Xarchie*aboutShell*aboutLabel4.vertDistance:	10",
 "Xarchie*aboutShell*aboutLabel5.label:	\\ \\ \\ \\ \\ \\ \\ \\ \\ \\ \\ \\ \\ Prospero: info-prospero@isi.edu",
 "Xarchie*aboutShell*aboutLabel5.fromVert:	aboutLabel4",
+"Xarchie*aboutShell*aboutLabel6.label:	\\ \\ Archie servers: archie-admin@<archie-host>",
+"Xarchie*aboutShell*aboutLabel6.fromVert:	aboutLabel5",
 "Xarchie*aboutShell*aboutDoneButton.label:	Dismiss",
-"Xarchie*aboutShell*aboutDoneButton.fromVert:	aboutLabel5",
+"Xarchie*aboutShell*aboutDoneButton.fromVert:	aboutLabel6",
 "Xarchie*aboutShell*aboutDoneButton.translations:#override\\n\
 	<BtnDown>,<BtnUp>:	about-done() \\n",
 "Xarchie*ftpTraceShell.title:		Xarchie Ftp Trace",
@@ -517,18 +523,34 @@
      <BtnUp>:           notify() unhighlight() MenuPopdown()",
 "Xarchie*setHostMenu.label:	Archie Host",
 "Xarchie*hostMenu.label:		Archie Host",
-"Xarchie*hostMenuItem0.label:	archie.sura.net        (USA-MD)",
-"Xarchie*hostMenuItem1.label:	archie.ans.net         (USA-NY)",
-"Xarchie*hostMenuItem2.label:	archie.rutgers.edu     (USA-NJ)",
-"Xarchie*hostMenuItem3.label:	archie.unl.edu         (USA-NE)",
-"Xarchie*hostMenuItem4.label:	archie.funet.fi        (Finland/Europe)",
-"Xarchie*hostMenuItem5.label:	archie.au              (Australia)",
-"Xarchie*hostMenuItem6.label:	archie.doc.ic.ac.uk    (GB/Ireland)",
-"Xarchie*hostMenuItem7.label:	archie.wide.ad.jp      (Japan)",
-"Xarchie*hostMenuItem8.label:	archie.ncu.edu.tw      (Taiwan)",
-"Xarchie*hostMenuItem9.label:	archie.nz              (New Zealand)",
-"Xarchie*hostMenuItem10.label:	archie.th-darmstadt.de (Germany)",
-"Xarchie*numHosts:               11",
+"Xarchie*hostMenuItem0.label:  archie.sura.net(1526)     USA (MD)",
+"Xarchie*hostMenuItem1.label:  archie.sura.net           USA (MD)",
+"Xarchie*hostMenuItem2.label:  archie.ans.net            USA (NY)",
+"Xarchie*hostMenuItem3.label:  archie.rutgers.edu        USA (NJ)",
+"Xarchie*hostMenuItem4.label:  archie.unl.edu            USA (NE)",
+"Xarchie*hostMenuItem5.label:  archie.internic.net       USA (NJ)",
+"Xarchie*hostMenuItem6.label:  archie.au                 Australia",
+"Xarchie*hostMenuItem7.label:  archie.uni-linz.ac.at     Austria",
+"Xarchie*hostMenuItem8.label:  archie.univie.ac.at       Austria",
+"Xarchie*hostMenuItem9.label:  archie.cs.mcgill.ca       Canada",
+"Xarchie*hostMenuItem10.label: archie.uqam.ca            Canada",
+"Xarchie*hostMenuItem11.label: archie.funet.fi           Finland",
+"Xarchie*hostMenuItem12.label: archie.univ-rennes1.fr    France",
+"Xarchie*hostMenuItem13.label: archie.th-darmstadt.de    Germany",
+"Xarchie*hostMenuItem14.label: archie.ac.il              Israel",
+"Xarchie*hostMenuItem15.label: archie.unipi.it           Italy",
+"Xarchie*hostMenuItem16.label: archie.wide.ad.jp         Japan",
+"Xarchie*hostMenuItem17.label: archie.hana.nm.kr         Korea",
+"Xarchie*hostMenuItem18.label: archie.sogang.ac.kr       Korea",
+"Xarchie*hostMenuItem19.label: archie.uninett.no         Norway",
+"Xarchie*hostMenuItem20.label: archie.rediris.es         Spain",
+"Xarchie*hostMenuItem21.label: archie.luth.se            Sweden",
+"Xarchie*hostMenuItem22.label: archie.switch.ch          Switzerland",
+"Xarchie*hostMenuItem23.label: archie.twnic.net          Taiwan",
+"Xarchie*hostMenuItem24.label: archie.ncu.edu.tw         Taiwan",
+"Xarchie*hostMenuItem25.label: archie.doc.ic.ac.uk       United Kingdom",
+"Xarchie*hostMenuItem26.label: archie.hensa.ac.uk        United Kingdom",
+"Xarchie*numHosts:               27",
 "Xarchie*hostMenu*leftMargin:	15",
 "Xarchie*hostMenu.translations:#override\\n\
      <EnterWindow>:     highlight()             \\n\
