@@ -2,7 +2,7 @@
 NULL,
 "NAME\n",
 "     xarchie - X11 browser interface  to\n",
-"     archie, version 2.0\n",
+"     archie, version 2.0.9\n",
 "\n",
 NULL,
 "SYNOPSIS\n",
@@ -965,9 +965,22 @@ NULL,
 "          Sets the host to which  Archie\n",
 "          queries  will  be sent. Please\n",
 "          be careful to use the  nearest\n",
-"          possible  host. The default is\n",
-"          \"archie.sura.net\".        This\n",
-"          option   corresponds   to  the\n",
+"          possible    host.    You   can\n",
+"          specify hostnames using either\n",
+"          the symbolic name or by giving\n",
+"          its numeric IP  address  (four\n",
+"          octets  separated by periods).\n",
+"          In  either   case,   you   can\n",
+"          specify  the port at which the\n",
+"          Prospero server should be con-\n",
+"          tacted   by   giving   it   in\n",
+"          parentheses  immediately  fol-\n",
+"          lowing    the   hostname   (no\n",
+"          spaces).\n",
+"\n",
+"          The         default         is\n",
+"          \"archie.sura.net(1526)\".  This\n",
+"          option  corresponds   to   the\n",
 "          archieHost resource.\n",
 "\n",
 "     -search type\n",
@@ -991,7 +1004,6 @@ NULL,
 "\n",
 "     -c   Equivalent        to        \"-\n",
 "          search subcase\".\n",
-"\n",
 "     -r   Equivalent        to        \"-\n",
 "          search regexp\".\n",
 "\n",
@@ -1057,11 +1069,11 @@ NULL,
 "          determine  the  visual type of\n",
 "          your  display  and   use   the\n",
 "          proper  color resources. If it\n",
-"          gets it wrong, you  can  over-\n",
-"          ride the default by specifying\n",
-"          one  of  these  options.  They\n",
-"          correspond  to  the visualType\n",
-"          resource.\n",
+"          gets   it   wrong,   you   can\n",
+"          override the default by speci-\n",
+"          fying one  of  these  options.\n",
+"          They correspond to the visual-\n",
+"          Type resource.\n",
 "\n",
 "     -debug level or -D level\n",
 "          Sets  the  Prospero  debugging\n",
@@ -1125,10 +1137,10 @@ NULL,
 "          Sets  the  search   mode   for\n",
 "          Archie  queries.  This  can be\n",
 "          one of exact, substr, subcase,\n",
-"          regexp, exactSubstr, exactSub-\n",
-"          case, or exactRegexp.  See the\n",
-"          section  describing  the  Set-\n",
-"          tings  Panel  in  the   USER'S\n",
+"          regexp,           exactSubstr,\n",
+"          exactSubcase, or  exactRegexp.\n",
+"          See the section describing the\n",
+"          Settings Panel in  the  USER'S\n",
 "          GUIDE for a description of the\n",
 "          various  search  types.    The\n",
 "          default  search mode is exact.\n",
@@ -1211,6 +1223,7 @@ NULL,
 "          resource can be set  with  the\n",
 "          -nice  option  or  on the Set-\n",
 "          tings Panel.\n",
+"\n",
 "     maxHits\n",
 "          Sets  the  maximum  number  of\n",
 "          matches allowed per query. The\n",
@@ -1481,17 +1494,16 @@ NULL,
 "     On  color  displays,  there  is  an\n",
 "     extra  Form  widget  named  \"color\"\n",
 "     created as the only  child  of  the\n",
-"     toplevel   shell,   and  all  other\n",
-"     widgets are children  of  it.  This\n",
-"     allows   resources  that  are  only\n",
-"     applicable for  color  displays  to\n",
-"     use   the   prefix  \"Xarchie.color\"\n",
-"     while     generally      applicable\n",
-"     resources should use the \"Xarchie*\"\n",
-"     prefix. On gray-scale displays, the\n",
-"     extra  widget  is  named \"gray\". On\n",
-"     monochrome   displays,   no   extra\n",
-"     widget is created.\n",
+"     toplevel shell, and all other widg-\n",
+"     ets are children of it. This allows\n",
+"     resources  that are only applicable\n",
+"     for color displays to use the  pre-\n",
+"     fix \"Xarchie.color\" while generally\n",
+"     applicable resources should use the\n",
+"     \"Xarchie*\"  prefix.  On  gray-scale\n",
+"     displays, the extra widget is named\n",
+"     \"gray\".  On monochrome displays, no\n",
+"     extra widget is created.\n",
 "\n",
 "     The  XfwfMultiList  widget   is   a\n",
 "     modification of the standard Athena\n",
@@ -1790,7 +1802,12 @@ NULL,
 "     hosts  to  the menu by adding label\n",
 "     resources     for      the      new\n",
 "     hostMenuItem's  and  increasing the\n",
-"     value of Xarchie.numHosts.\n",
+"     value of Xarchie.numHosts.  Xarchie\n",
+"     parses  the labels to determine the\n",
+"     hostname: anything up to whitespace\n",
+"     constitutes   the   hostname   (and\n",
+"     optional  port  number),   anything\n",
+"     after is simply commentary.\n",
 "\n",
 NULL,
 " Translation Actions\n",
@@ -1927,7 +1944,6 @@ NULL,
 "          clicking  with  Shift  on  the\n",
 "          \"<<<\" button (browserUpButton)\n",
 "          or by hitting the \"Home\" key.\n",
-"\n",
 "     browser-open-directories()\n",
 "          Expands selected  directories.\n",
 "          If  the  browser  was expanded\n",
@@ -1943,15 +1959,16 @@ NULL,
 "          FTP  into a temporary file and\n",
 "          displays them using View  win-\n",
 "          dows.\n",
+"\n",
 "     browser-open-all()\n",
 "          Opens the  selected  items  by\n",
 "          expanding selected directories\n",
 "          and retrieving selected  files\n",
 "          for viewing.  By default, this\n",
 "          is invoked by selecting \"Open\"\n",
-"          from  the  File  menu,  or  by\n",
-"          typing \"Meta-O\"  in  any  non-\n",
-"          text widget.\n",
+"          from the File menu, or by typ-\n",
+"          ing \"Meta-O\" in  any  non-text\n",
+"          widget.\n",
 "\n",
 NULL,
 "  Settings actions\n",
@@ -2077,6 +2094,7 @@ NULL,
 "          \"File\"   menu   or  by  typing\n",
 "          \"Meta-S\"   in   any   non-Text\n",
 "          widget.\n",
+"\n",
 "     file-load()\n",
 "          Pops up the  File  panel,  and\n",
 "          resets  its values in prepara-\n",
@@ -2155,6 +2173,7 @@ NULL,
 "     handler that prints a  message  and\n",
 "     dies, possibly leaving a large core\n",
 "     dump somewhere.\n",
+"\n",
 "     Errors due  to  incorrect  resource\n",
 "     specifications  cause an error mes-\n",
 "     sage on stderr,  but  do  not  kill\n",
@@ -2236,11 +2255,16 @@ NULL,
 "\n",
 NULL,
 " Reporting Bugs\n",
-"     If you  have  any  questions  about\n",
-"     Archie  itself,  write  to  archie-\n",
-"     l@cs.mcgill.ca. If you  have  ques-\n",
-"     tions   about  Prospero,  write  to\n",
-"     info-prospero@isi.edu.\n",
+"     If you have problems with or  ques-\n",
+"     tions  about  an  individual Archie\n",
+"     server site,  contact  archie-admin\n",
+"     at that site. If you have any ques-\n",
+"     tions about Archie itself, write to\n",
+"     info@bunyip.com.  If you have ques-\n",
+"     tions  about  Prospero,  write   to\n",
+"     info-prospero@isi.edu.  The  USENET\n",
+"     newsgroup  comp.archives.admin  may\n",
+"     also be helpful.\n",
 "\n",
 "     If you have a problem, please  read\n",
 "     the  \"Known  Bugs\"  section  first,\n",
@@ -2272,7 +2296,8 @@ NULL,
 "     are in charge of the Archie project\n",
 "     itself.  Individual archie servers,\n",
 "     however,  are maintained locally at\n",
-"     each server site.\n",
+"     each    server    site     (archie-\n",
+"     admin@<server-host>).\n",
 "\n",
 NULL,
 "AUTHOR\n",
@@ -2283,6 +2308,7 @@ NULL,
 "     Original standalone archie  program\n",
 "     by Brendan Kehoe,\n",
 "     (brendan@cs.widener.edu).\n",
+"\n",
 "     Original Prospero archie program by\n",
 "     Clifford Neuman,\n",
 "     (bcn@isi.edu).\n",
