@@ -3,6 +3,7 @@
  *
  * George Ferguson, ferguson@cs.rochester.edu, 23 Apr 1993.
  * 13 May 1993: Cleanups.
+ *  5 Jul 1994: Do it without modifying the stupid original.
  *
  */
 
@@ -23,8 +24,10 @@ tildeExpand(file)
 char *file;
 {
     static char filename[MAXPATHLEN];
+    char name[64];
     struct passwd *pwe;
-    char *name,*home;
+    char *home;
+    int i;
 
     /* Must start with tilde */
     if (*file != '~')
@@ -32,12 +35,17 @@ char *file;
     /* Set default return value in case tilde expansion fails */
     strcpy(filename,file);
     /* Skip tilde */
-    name = ++file;
+    file += 1;
     /* Gather name following tilde (if any) */
-    while (*file != '\0' && *file != '/')
+    i = 0;
+    while (*file != '\0' && *file != '/') {
+	name[i++] = *file++;
+    }
+    name[i] = '\0';
+    /* Skip slash (if any) */
+    if (*file == '/') {
 	file += 1;
-    if (*file != '\0')
-	*file++ = '\0';
+    }
     if (*name == '\0') {				/* ~/... */
 	if ((pwe=getpwuid(getuid())) != NULL) {
 	    home = pwe->pw_dir;
@@ -53,6 +61,10 @@ char *file;
 	    return(filename);
 	}
     }
-    sprintf(filename,"%s/%s",home,file);
+    if (*file != '\0') {
+	sprintf(filename,"%s/%s",home,file);
+    } else {
+	strcpy(filename,home);
+    }
     return(filename);
 }
