@@ -3,6 +3,10 @@
  *
  * George Ferguson, ferguson@cs.rochester.edu, 2 Nov 1991.
  * Version 2.0: 23 Apr 1993.
+ * 28 Apr 1993: Change default host to "archie.sura.net(1526)".
+ * 13 May 1993: Apply icon resources to realToplevel.
+ *		Don't call XtMapWidget() or -iconic is ignored.
+ *		Apply tilde expansion to initial value of ftpLocalDir resource.
  */
 
 #include <stdio.h>
@@ -48,6 +52,7 @@
 #include "view-file.h"
 #include "username.h"
 #include "hostname.h"
+#include "tilde.h"
 #include "syntax.h"
 #include "xarchie.xbm"
 #include "busy.xbm"
@@ -241,9 +246,6 @@ char **argv;
     initHelpPanel();
 #endif
     initMisc();
-    /* Set icon, then map (must be this order!) */
-    setIconStatus(0);
-    XtMapWidget(realToplevel);
     /* Enable WM_DELETE_WINDOW processing */
     (void)XSetWMProtocols(display,XtWindow(realToplevel),&WM_DELETE_WINDOW,1);
     status0("Ready");
@@ -492,8 +494,12 @@ initMisc()
     addr = XtMalloc(strlen(user)+
 		    strlen(host)+strlen(appResources.ftpMailAddress));
     sprintf(addr,appResources.ftpMailAddress,user,host);
-    /* Memory leak, but only happens once */
     appResources.ftpMailAddress = addr;
+    /* Do initial tilde expansion if needed */
+    if (appResources.ftpLocalDir && *(appResources.ftpLocalDir) == '~') {
+	appResources.ftpLocalDir =
+	    XtNewString(tildeExpand(appResources.ftpLocalDir));
+    }
     /* Use the default icons unless overridden */
     if (appResources.defaultIcon == None) {
 	appResources.defaultIcon =
@@ -505,6 +511,8 @@ initMisc()
 	    XCreateBitmapFromData(display,root,busy_bits,
 				  busy_width,busy_height);
     }
+    /* Tell the world about the initial icons */
+    setIconStatus(0);
 }
 
 /*	-	-	-	-	-	-	-	-	*/
@@ -705,5 +713,5 @@ Boolean state;
     }
     XtSetArg(args[0],XtNiconName,name);
     XtSetArg(args[1],XtNiconPixmap,pixmap);
-    XtSetValues(toplevel,args,2);
+    XtSetValues(realToplevel,args,2);
 }
